@@ -9,6 +9,10 @@ assert (
 ), "Please export your API token in the HCLOUD_TOKEN environment variable"
 token = environ["HCLOUD_TOKEN"]
 
-client = Client(token=token)
+client = Client(
+    token=token,
+    application_name="examples",
+    application_version="unknown",
+)
 servers = client.servers.get_all()
 print(servers)
