@@ -15,12 +15,12 @@ from hcloud.floating_ips import FloatingIP
     ],
 )
 def test_eq(value):
-    assert value == value
+    assert value.__eq__(value)
 
 
 class TestFloatingIP:
     def test_created_is_datetime(self):
-        floatingIP = FloatingIP(id=1, created="2016-01-30T23:50+00:00")
-        assert floatingIP.created == datetime.datetime(
+        floating_ip = FloatingIP(id=1, created="2016-01-30T23:50+00:00")
+        assert floating_ip.created == datetime.datetime(
             2016, 1, 30, 23, 50, tzinfo=timezone.utc
         )
